@@ -11,6 +11,22 @@ from combine_pvalues_discrete.tools import sign_test, assert_matching_p_values
 
 n_samples = 10000
 
+@mark.parametrize(
+	  "  p  , alternative, result",
+	[
+	  ( 0.01, "less"     , 0.01   ),
+	  ( 0.01, "greater"  , 0.99   ),
+	  ( 0.01, "two-sided", 0.02   ),
+	  ( 0.99, "less"     , 0.99   ),
+	  ( 0.99, "greater"  , 0.01   ),
+	  ( 0.99, "two-sided", 0.02   ),
+	])
+def test_single_p(p,alternative,result):
+	assert np.isclose(
+			combine([CTR(p)],alternative=alternative).pvalue,
+			result
+		)
+
 def test_assert_one_sided_good():
 	assert_one_sided("less")
 	assert_one_sided("greater")
